Crate wio_lite_mg126

Crate wio_lite_mg126 

Re-exports

pub use atsamd_hal as hal;
pub use hal::pac;

Modules

delay
Delays
gpio
GPIO
pad
prelude
Import the prelude to gain convenient access to helper traits
rtc
Real-time clock/counter
sercom
Configure the SERCOM peripherals
sleeping_delay
Delays with WFI sleep while we wait using a timer
spi_commonDeprecated
thumbv6m
time
Time units
timer_params
helper struct to calculate divider & cycles settings for timers.
timer_traits

Structs

Pins
Maps the pins to their arduino names and the numbers printed on the board. Information pulled from datasheet and board files for arduino IDE : https://wiki.seeedstudio.com/Wio-Lite-MG126/#tech-support

Enums

ResetCause
ResetCause represents the reason the MCU was reset.

Functions

i2c_master
Convenience for setting up the labelled SDA, SCL pins to operate as an I2C master running at the specified frequency.
reset_cause
Returns the cause of the last reset.
serial_number
Returns the serial number of the chip as an array of bytes. The serial number is only guaranteed to be unique if all 16 bytes are used.
spi_master
Convenience function for setting up the D24/SCK, D23/MOSI, and D22/MISO pins as a SPI Master.
split_serial_number
Returns the serial number of the chip as 4 32-bit integers. The serial number is only guaranteed to be unique if all 128 bits are used.
uart
Convenience for setting up the D0 and D1 pins to operate as UART RX/TX (respectively) running at the specified baud.

Attribute Macros

entry